pub struct FcmNotification { /* private fields */ }Expand description
The main service for sending FCM notifications.
This struct provides methods to authenticate with Google OAuth2 and send notifications using the Firebase Cloud Messaging API.
Implementations
Sourceimpl FcmNotification
impl FcmNotification