pub struct ServiceAccount {
pub account_type: String,
pub project_id: String,
pub private_key_id: String,
pub private_key: String,
pub client_email: String,
pub client_id: String,
pub auth_uri: String,
pub token_uri: String,
pub auth_provider_x509_cert_url: String,
pub client_x509_cert_url: String,
pub universe_domain: String,
}Expand description
Represents a Firebase service account, loaded from a JSON file.
This struct is used to store the credentials required to authenticate with Google OAuth2 and send FCM notifications.
Fields
account_type: Stringproject_id: Stringprivate_key_id: Stringprivate_key: Stringclient_email: Stringclient_id: Stringauth_uri: Stringtoken_uri: Stringauth_provider_x509_cert_url: Stringclient_x509_cert_url: Stringuniverse_domain: StringTrait Implementations
Sourceimpl Clone for ServiceAccount
impl Clone for ServiceAccount
Sourcefn clone(&self) -> ServiceAccount
fn clone(&self) -> ServiceAccount
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServiceAccount
impl Debug for ServiceAccount
Sourceimpl<'de> Deserialize<'de> for ServiceAccount
impl<'de> Deserialize<'de> for ServiceAccount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more